==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translation>Cotation</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translation type="obsolete">Paramètres par défaut cotation</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Paramètres cotation</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Valeurs par défaut pour les nouveaux dessins</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Scientific</source>
        <translation>Scientifique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Décimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Génie mécanique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architecture</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Fractionnel</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Degrés décimaux</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Deg/min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Grades</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radians</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Unités de géomètre</translation>
    </message>
    <message>
        <location line="+198"/>
        <source>Unit / Format</source>
        <translation>Unité / format</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>L&apos;unité de dessin doivent être &apos;Inch&apos; ou &apos;Foot&apos; pour afficher des étiquettes de dimension dans des formats &apos;architecturale&apos; ou &apos;ingénierie&apos;. Format changé en &apos;décimal&apos;.</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">L&apos;unité de dessin doivent être &apos;Inch&apos; pour afficher des étiquettes de dimension dans des formats &apos;architecturale&apos; ou &apos;ingénierie&apos;. Format changé en &apos;décimal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Tailles</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Garder les proportions</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Hauteur du texte :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Décalage de la ligne d&apos;attache :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Extension de la ligne d&apos;attache :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Espacement de la ligne de cote :</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Taille de flèche :</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Facteur d&apos;échelle :</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Style de flèche</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Graduation architecturale</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Police</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Police:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Format de l&apos;étiquette</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Cotation linéaire</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Format :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>P&amp;récision :</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Afficher les zéros de fin</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Cotation angulaire</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>&amp;Format :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>P&amp;récision :</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Prévisualisation</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translation>Cotation</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translation type="obsolete">Paramètres par défaut cotation</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Paramètres cotation</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Valeurs par défaut pour les nouveaux dessins</translation>
    </message>
    <message>
        <location line="+110"/>
        <source>point</source>
        <translation>Point</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>comma</source>
        <translation>Comma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>space</source>
        <translation>Espace</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Scientific</source>
        <translation>Scientifique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Décimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Génie mécanique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architecture</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Fractionnel</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Degrés décimaux</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Deg/min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Grades</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radians</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Unités de géomètre</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Unit / Format</source>
        <translation>Unité / format</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">L&apos;unité de dessin doivent être &apos;Inch&apos; ou &apos;Foot&apos; pour afficher des étiquettes de dimension dans des formats &apos;architecturale&apos; ou &apos;ingénierie&apos;. Format changé en &apos;décimal&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>L&apos;unité de dessin doivent être &apos;Inch&apos; pour afficher des étiquettes de dimension dans des formats &apos;architecturale&apos; ou &apos;ingénierie&apos;. Format changé en &apos;décimal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Tailles</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Garder les proportions</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Hauteur du texte :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Décalage de la ligne d&apos;attache :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Extension de la ligne d&apos;attache :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Espacement de la ligne de cote :</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Taille de flèche :</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Facteur d&apos;échelle :</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Style de flèche</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Graduation architecturale</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Police</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Police:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Number Format</source>
        <translation>Format des numéros</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Decimal separator:</source>
        <translation>Séparateur décimal :</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Label Format</source>
        <translation>Format de l&apos;étiquette</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Cotation linéaire</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Format :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>P&amp;récision :</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Afficher les zéros de fin</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Cotation angulaire</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>&amp;Format :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>P&amp;récision :</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Prévisualisation</translation>
    </message>
</context>
</TS>
